@@ -1,6 +1,5 @@
 """crossref reader for commonmeta-py"""
-from typing import Optional, TypedDict
-from functools import reduce
+from typing import Optional
 import requests
 from pydash import py_
 
@@ -14,13 +13,9 @@ from ..utils import (
 from ..base_utils import wrap, compact, presence, sanitize
 from ..author_utils import get_authors
 from ..date_utils import get_date_from_date_parts
-from ..doi_utils import doi_as_url, doi_from_url, get_doi_ra, crossref_api_url
+from ..doi_utils import doi_as_url, doi_from_url, get_doi_ra, get_crossref_member, crossref_api_url
 from ..constants import (
-    CR_TO_BIB_TRANSLATIONS,
-    CR_TO_CP_TRANSLATIONS,
-    CR_TO_DC_TRANSLATIONS,
-    CR_TO_RIS_TRANSLATIONS,
-    CR_TO_SO_TRANSLATIONS,
+    CR_TO_CM_TRANSLATIONS,
     Commonmeta,
 )
 
@@ -31,7 +26,7 @@ def get_crossref(pid: str, **kwargs) -> dict:
     if doi is None:
         return {"state": "not_found"}
     url = crossref_api_url(doi)
-    response = requests.get(url, kwargs, timeout=5)
+    response = requests.get(url, kwargs, timeout=10)
     if response.status_code != 200:
         return {"state": "not_found"}
     return response.json().get("message", {})
@@ -49,20 +44,14 @@ def read_crossref(data: Optional[dict], **kwargs) -> Commonmeta:
     read_options = kwargs or {}
 
     doi = meta.get("DOI", None)
-    pid = doi_as_url(doi)
+    id_ = doi_as_url(doi)
     resource_type = meta.get("type", {}).title().replace("-", "")
-    types = {
-        "resourceTypeGeneral": CR_TO_DC_TRANSLATIONS.get(resource_type, None) or "Text",
-        "resourceType": resource_type,
-        "schemaOrg": CR_TO_SO_TRANSLATIONS.get(resource_type, None) or "CreativeWork",
-        "citeproc": CR_TO_CP_TRANSLATIONS.get(resource_type, None) or "article-journal",
-        "bibtex": CR_TO_BIB_TRANSLATIONS.get(resource_type, None) or "misc",
-        "ris": CR_TO_RIS_TRANSLATIONS.get(resource_type, None) or "GEN",
-    }
+    type_ = CR_TO_CM_TRANSLATIONS.get(resource_type, 'Other')
+
     if meta.get("author", None):
         creators = get_authors(from_citeproc(wrap(meta.get("author"))))
     else:
-        creators = [{"nameType": "Organizational", "name": ":(unav)"}]
+        creators = None
 
     def editor_type(item):
         item["ContributorType"] = "Editor"
@@ -79,28 +68,25 @@ def read_crossref(data: Optional[dict], **kwargs) -> Commonmeta:
         titles = [{"title": sanitize(title)}]
     else:
         titles = []
-    publisher = meta.get("publisher", None)
 
-    date_created = py_.get(meta, "created.date-time")
-    date_issued = py_.get(meta, "issued.date-time") or get_date_from_date_parts(
-        meta.get("issued", None)
-    )
-    date_deposited = py_.get(meta, "deposited.date-time")
-    date_indexed = py_.get(meta, "indexed.date-time")
-    date_registered = py_.get(meta, "registered.date-time") or date_created
-    date_published = date_issued or date_created
-    date_updated = date_deposited or date_indexed
-    dates = [{"date": date_published, "dateType": "Issued"}]
-    if date_updated is not None:
-        dates.append({"date": date_updated, "dateType": "Updated"})
-    publication_year = int(date_published[:4]) if date_published else None
+    member_id = meta.get("member", None)
+    # TODO: get publisher from member_id almost always return publisher name, but sometimes does not
+    if member_id is not None:
+        publisher = get_crossref_member(member_id)
+    else:
+        publisher = meta.get("publisher", None)
+
+    date: dict = {}
+    date['submitted'] = None
+    date['accepted'] = py_.get(meta, "accepted.date-time")
+    date['published'] = py_.get(meta, "issued.date-time") or get_date_from_date_parts(
+        meta.get("issued", None)) or py_.get(meta, "created.date-time")
+    date['updated'] = py_.get(meta, "updated.date-time") or py_.get(meta, "deposited.date-time")
 
     license_ = meta.get("license", None)
     if license_ is not None:
         license_ = normalize_cc_url(license_[0].get("URL", None))
-        rights = [dict_to_spdx({"rightsUri": license_})] if license_ else None
-    else:
-        rights = None
+        license_ = dict_to_spdx({"url": license_}) if license_ else None
 
     issns = meta.get("issn-type", None)
     if issns is not None:
@@ -112,8 +98,6 @@ def read_crossref(data: Optional[dict], **kwargs) -> Commonmeta:
         issn = issn["value"] if issn else None
     else:
         issn = None
- 
-    references = [get_reference(i) for i in wrap(meta.get("reference", []))]
 
     if resource_type == "JournalArticle":
         container_type = "Journal"
@@ -170,36 +154,31 @@ def read_crossref(data: Optional[dict], **kwargs) -> Commonmeta:
 
     return {
         # required properties
-        "pid": pid,
+        "id": id_,
+        "type": type_,
         "doi": doi,
         "url": url,
         "creators": creators,
         "titles": presence(titles),
-        "types": types,
         "publisher": publisher,
-        "publication_year": publication_year,
+        "date": compact(date),
         # recommended and optional properties
         "subjects": presence(subjects),
         "contributors": contributors,
-        "dates": dates,
         "language": meta.get("language", None),
         "alternate_identifiers": None,
         "sizes": None,
         "formats": None,
         "version": meta.get("version", None),
-        "rights": rights,
+        "license": license_,
         "descriptions": descriptions,
         "geo_locations": None,
         "funding_references": presence(funding_references),
         "references": references,
         # other properties
-        "date_created": date_created,
-        "date_registered": date_registered,
-        "date_published": date_published,
-        "date_updated": date_updated,
         "content_url": presence(meta.get("contentUrl", None)),
         "container": container,
-        "agency": get_doi_ra(pid),
+        "provider": get_doi_ra(id_),
         "state": state,
         "schema_version": None,
     } | read_options
