@@ -1,6 +1,7 @@
 """schema_org reader for commonmeta-py"""
 from typing import Optional
 import json
+from collections import defaultdict
 import requests
 from pydash import py_
 from bs4 import BeautifulSoup
@@ -18,14 +19,11 @@ from ..utils import (
 from ..base_utils import wrap, compact, presence, parse_attributes, sanitize
 from ..author_utils import get_authors
 from ..date_utils import get_iso8601_date, strip_milliseconds
-from ..doi_utils import doi_from_url
+from ..doi_utils import doi_from_url, get_doi_ra
 from ..constants import (
-    SO_TO_BIB_TRANSLATIONS,
-    SO_TO_CP_TRANSLATIONS,
-    SO_TO_DC_TRANSLATIONS,
+    SO_TO_CM_TRANSLATIONS,
     SO_TO_DC_RELATION_TYPES,
     SO_TO_DC_REVERSE_RELATION_TYPES,
-    SO_TO_RIS_TRANSLATIONS,
     Commonmeta,
 )
 
@@ -35,7 +33,7 @@ def get_schema_org(pid: str, **kwargs) -> dict:
     if pid is None:
         return {"state": "not_found"}
     url = pid
-    response = requests.get(url, kwargs, timeout=5)
+    response = requests.get(url, kwargs, timeout=10)
     if response.status_code != 200:
         return {"state": "not_found"}
 
@@ -71,35 +69,19 @@ def read_schema_org(data: Optional[dict], **kwargs) -> Commonmeta:
 
     read_options = kwargs or {}
 
-    pid = meta.get("@id", None)
-    doi = doi_from_url(pid)
-    types = None
-
+    id_ = meta.get("@id", None)
     # if id.blank? && URI(meta.fetch('@id', '')).host == 'doi.org'
-    if pid is None:
-        pid = meta.get("identifier", None)
-    pid = normalize_id(pid)
-
-    schema_org = meta.get("@type") if meta.get("@type", None) else "CreativeWork"
-    resource_type_general = SO_TO_DC_TRANSLATIONS.get(schema_org, None)
-    types = compact(
-        {
-            "resourceTypeGeneral": resource_type_general,
-            "resourceType": meta.get("additionalType", None),
-            "schemaOrg": schema_org,
-            "citeproc": SO_TO_CP_TRANSLATIONS.get(schema_org, None)
-            or "article-journal",
-            "bibtex": SO_TO_BIB_TRANSLATIONS.get(schema_org, None) or "misc",
-            "ris": SO_TO_RIS_TRANSLATIONS.get(resource_type_general, None) or "GEN",
-        }
-    )
+    if id_ is None:
+        id_ = meta.get("identifier", None)
+    id_ = normalize_id(id_)
+    type_ = SO_TO_CM_TRANSLATIONS.get(meta.get("@type", None), 'Other')
+    additional_type = meta.get("additionalType", None)
     authors = meta.get("author", None) or meta.get("creator", None)
     # Authors should be an object, if it's just a plain string don't try and parse it.
     if not isinstance(authors, str):
         creators = get_authors(from_schema_org_creators(wrap(authors)))
     else:
         creators = authors
-    print(creators)
     contributors = presence(
         get_authors(from_schema_org_creators(wrap(meta.get("editor", None))))
     )
@@ -111,35 +93,28 @@ def read_schema_org(data: Optional[dict], **kwargs) -> Commonmeta:
     else:
         titles = None
 
-    published_date = strip_milliseconds(meta.get("datePublished", None))
-    updated_date = strip_milliseconds(meta.get("dateModified", None))
-    dates = [{"date": published_date, "dateType": "Issued"}]
-    if updated_date is not None:
-        dates.append({"date": updated_date, "dateType": "Updated"})
-    publication_year = int(published_date[0:4]) if published_date else None
+    date: dict = defaultdict(list)
+    date['published'] = strip_milliseconds(meta.get("datePublished", None))
+    date['updated'] = strip_milliseconds(meta.get("dateModified", None))
 
-    publisher = parse_attributes(
-        meta.get("publisher", None), content="name", first=True
-    )
+    publisher = meta.get("publisher", None)
+    if publisher is not None:
+        publisher = py_.omit(publisher, ["@type", "logo", "url", "disambiguatingDescription"])
 
     license_ = meta.get("license", None)
     if license_ is not None:
         license_ = normalize_cc_url(license_)
-        rights = [dict_to_spdx({"rightsUri": license_})] if license_ else None
-    else:
-        rights = None
+        license_ = dict_to_spdx({"url": license_}) if license_ else None
 
-    issn = py_.get(meta, "isPartOf.issn")
-    cet = "includedInDataCatalog" if schema_org in ["Dataset", "Periodical"] else None
-    if cet is not None:
+    if type_ == "Dataset":
         url = parse_attributes(
-            from_schema_org(meta.get(cet, None)), content="url", first=True
+            from_schema_org(meta.get('includedInDataCatalog', None)), content="url", first=True
         )
         container = compact(
             {
-                "type": "DataRepository" if schema_org == "Dataset" else "Periodical",
+                "type": "DataRepository",
                 "title": parse_attributes(
-                    from_schema_org(meta.get(cet, None)), content="name", first=True
+                    from_schema_org(meta.get('includedInDataCatalog', None)), content="name", first=True
                 ),
                 "identifier": url,
                 "identifierType": "URL" if url is not None else None,
@@ -149,7 +124,8 @@ def read_schema_org(data: Optional[dict], **kwargs) -> Commonmeta:
                 "lastPage": meta.get("pageEnd", None),
             }
         )
-    elif schema_org in ("Article", "BlogPosting"):
+    elif type_ == "Article":
+        issn = py_.get(meta, "isPartOf.issn")
         url = py_.get(meta, "publisher.url")
         container = compact(
             {
@@ -204,37 +180,37 @@ def read_schema_org(data: Optional[dict], **kwargs) -> Commonmeta:
         schema_org_geolocation(i) for i in wrap(meta.get("spatialCoverage", None))
     ]
     alternate_identifiers = None
+    provider = get_doi_ra(id_) if doi_from_url(id_) else parse_attributes(
+            meta.get("provider", None), content="name", first=True
+        )
     state = None
 
     return {
         # required attributes
-        "pid": pid,
-        "doi": doi,
+        "id": id_,
+        "type": type_,
         "url": normalize_url(meta.get("url", None)),
         "creators": creators,
         "titles": titles,
         "publisher": publisher,
-        "publication_year": publication_year,
-        "types": types,
+        "date": compact(date),
         # recommended and optional attributes
+        "additional_type": additional_type,
         "subjects": presence(subjects),
         "contributors": contributors,
-        "dates": dates,
         "language": language,
         "alternate_identifiers": alternate_identifiers,
         "sizes": None,
         "formats": None,
         "version": meta.get("version", None),
-        "rights": rights,
+        "license": license_,
         "descriptions": presence(descriptions),
         "geo_locations": presence(geo_locations),
         "funding_references": presence(funding_references),
         "references": presence(references),
         # optional attributes
         "container": container,
-        "agency": parse_attributes(
-            meta.get("provider", None), content="name", first=True
-        ),
+        "provider": provider,
         "state": state,
     } | read_options
 
