@@ -28,6 +28,6 @@ def write_citation(metadata):
     style_path = get_style_filepath(metadata.style)
     style = CitationStylesStyle(style_path, locale=metadata.locale)
     bib = CitationStylesBibliography(style, source, formatter.html)
-    citation = Citation([CitationItem(metadata.pid)])
+    citation = Citation([CitationItem(metadata.id)])
     bib.register(citation)
     return _clean_result(str(bib.bibliography()[0]))
